#include "console.h"
#include "msg.h"
namespace yx
{
	namespace IO
	{
		FILE *open_convicted(std::string filename, const char *mode)
		{
			const char* fn = filename.c_str();
			FILE *fd = fopen(fn, mode);
			if(fd == nullptr)
			{
				err (ERR_OPEN_FILE_FAILED, sys_mbs_to_wcs(filename).c_str(), errno);
				err (ERR_ABORTED);
				exit( E_ABORT_IO );
			}
			return fd;
		}
		
		void write_convicted(FILE *fd, void *buffer, long len)
		{
			int rlt = fwrite(buffer, len, 1, fd);
			if(rlt != 1)
			{
				err(ERR_WRITE_FILE_FAILED, errno);
				err(ERR_ABORTED);
				exit( E_ABORT_IO );
			}
		}

		size_t filelength(FILE *f)
		{
			auto loc = ftell(f);
			fseek(f, 0, SEEK_END);
			size_t ret = ftell(f);
			fseek(f, loc, SEEK_SET);
			return ret;
		}
	}
	
	namespace File
	{
		std::string get_extention(std::string filename)
		{
			return filename.substr(filename.find_last_of('.') + 1);
		}
		
		std::string get_prefix(std::string filename)
		{
			return filename.substr(0, filename.find_last_of('.'));
		}
		
		std::string get_path(std::string filename, char ps)
		{
			return filename.substr(0, filename.find_last_of(ps));
		}
	}
	
	namespace String
	{
		std::string itos(int value)
		{
			std::string result;
			while(value)
			{
				result = (char)((value % 10) - '0') + result;
				value /= 10;
			}
			return result;
		}
	}
	
	namespace gra
	{
		void progress_bar(int prog, int total)
		{
			wprintf(L"\r%3d%% - [", prog * 100 / total);
			for(int i = 1; i <= 25; ++i)
			{
				if(i <= prog * 25 / total) putchar('#');
				else putchar(' ');
			}
			wprintf(L"]%d/%d", prog, total);
		}
	}
}
